# DXP

Data analysis and exploration library.

## Usage

### Data Population

DXP provides a library of commonly used functions,
and an executable with sane defaults
that will read in a CSV file for input,
and output another CSV file populated with values
from your custom `pop.py` file.

### Plotting Data

DXP uses Matplotlib to create plots of linear regressions
from an input file. Refer to `dplt -h` for
more information about usage.
